define("ckeditor/plugins/eplistgroup/plugin", [
	"jquery",
	"ckeditor/ckeditor"
], function ($, CKEDITOR) {

	/*
	 * @dictionary		ep.dict
	 *
	 * @translation		{TextAlignGroup}
	 */

	CKEDITOR.plugins.add( 'eplistgroup', {
		requires : [ 'menubutton','list' ],

		init: function( editor ){
			var menuGroup = 'listGroup',
				uiMenuItems = {},
				epDict = ep.dict('ep.dict'),
				translations = {
					tListGroup: epDict.translate('ListGroup')
				};

			// add menu group
			editor.addMenuGroup( menuGroup );

			// create menu entries, commands and event listener for different line heights
			uiMenuItems.numberedlist = {
				label : editor.lang.list.numberedlist,
				command : 'numberedlist',
				group : menuGroup
			};

			uiMenuItems.bulletedlist = {
				label : editor.lang.list.bulletedlist,
				command : 'bulletedlist',
				group : menuGroup,
			};

			// add items to the menu
			editor.addMenuItems( uiMenuItems );

			// create menu button
			editor.ui.add( 'eplistgroup', CKEDITOR.UI_MENUBUTTON,{
				label : translations.tListGroup,
				title : translations.tListGroup,
				modes : { wysiwyg : 1 },
				icon: this.path + 'images/listgroup.png',
				className : 'cke_off cke_button_numberedlist',
				onRender: function(){
					var self = this;

					currentClassName = self.className;

					// selection handling --> show current list type
					editor.on( 'selectionChange', function( ev ){
						var element = editor.getSelection().getStartElement(),
							button = $('#'+self._.id),
							listType,
							newClassName;

						if (element.$.tagName == "LI")
						{
							// get the list tag
							element = element.getParent();

							listType = element.$.tagName;

							if(!listType || listType == "OL"){
								newClassName = 'cke_button_numberedlist';
							}
							else{
								newClassName = 'cke_button_bulletedlist';
							}

							self.setState(listType ? CKEDITOR.TRISTATE_ON : CKEDITOR.TRISTATE_OFF);

							button.removeClass(currentClassName);
							button.addClass(newClassName);
							currentClassName = newClassName;
							}
						else
						{
							self.setState(CKEDITOR.TRISTATE_OFF);
						};
					});
				},
				onMenu : function(){
					return {
						numberedlist : CKEDITOR.TRISTATE_OFF,
						bulletedlist : CKEDITOR.TRISTATE_OFF
					};
				}
			});
		}
	});

	return CKEDITOR;

});
