/*
 * @copyright       © Copyright 2006-2019, epages GmbH, All Rights Reserved.
 *
 * @module          ep.fn.progressbar
 */

define("ep/fn/progressbar", [
    "jquery",
    "ep",
    "$tmpl!ep/fn/progressbar",

    "jquery/tmpl"
], function ($, ep, tmplProgressbar) {

    /**
     * Add a progressbar layer to the end of the document body.
     *
     * ### Examples
     * Show a progressbar layer on body.
     *
     * JavaScript:
     *
     *     ep.fn.progressbar();
     *
     * Show a progressbar layer on body with argument.
     *
     * JavaScript:
     *
     *     ep.fn.progressbar('start');
     *
     * Destroy progressbar.
     *
     * JavaScript:
     *
     *     ep.fn.progressbar('destroy');
     *
     * @param {String} action - An action for progressbar layer, possible values: 'start', 'destroy'.
     *
     * @method progressbar
     * @member jQuery
     *
     * @since 7.40.0
     */
    ep.fn.progressbar = function(action) {
        var progressbarRoot = $('.ep-progressbar-root'),
            actions = {
                'start': 1,
                'destroy': 2
            },
            classHide = 'ep-progressbar-hide',
            // from ep/fn/progressbar.css
            delay = 500,
            progressbarRoot,
            progressbarBar;

        action = action === undefined ? 'start' : action;

        // progressbar doesn't exist
        if (progressbarRoot.length === 0) {
            progressbarRoot = tmplProgressbar();
            $('body').append(progressbarRoot);
        }

        progressbarBar = progressbarRoot.find('.ep-progressbar-bar');
        progressbarBar.width(0);

        switch(actions[action]) {
            // case 'start'
            case 1:
                progressbarBar.width('100%');
                progressbarRoot.removeClass(classHide);

                window.setTimeout(function() {
                    progressbarRoot.addClass(classHide);
                    progressbarBar.width('0%');
                }, delay);

                break;

            // case 'destroy'
            case 2:
                progressbarRoot.remove();
                break;
        }
    };

    return ep;
});
