/*globals define, window*/

define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!ep/ui/simpledialog-test',
    'jquery',

    'ep/ui/simpledialog',
    '$ready!'
], function (QUnit, fixture, $, ep) {

    QUnit.module("ep/ui/simpledialog", {
        teardown: fixture.destroy
    });

    QUnit.fixtureVar = fixture;

    QUnit.asyncTest("widget test presence of methods", function () {


        // Check prototype methods.
        $.each([
            '_create',
            '_setOption',
            'destroy',
            'open',
            'close',
            '_close'
        ], function (i, fn) {
            QUnit.equal(
                $.isFunction($.ui.uiSimpledialog.prototype[fn]),
                true,
                '$.isFunction(' + fn + '):'
            );
        });

        QUnit.start();
    });

    QUnit.asyncTest("ep/ui/simpledialog", function () {
        // clear HTML fragments and initiate fixture
        $('#qunit-fixture').nextAll().remove();
        QUnit.fixtureVar.init();

        window.calledCallback = false;
        var button = [],
            layout = 'base';

        // Create.
        button[0] = ep('#dialog0').uiSimpledialog({
            autoOpen : true,
            content : $('<div id="content0">Some (awesome) content</div>')
        });
        button[1] = ep('#dialog1').uiSimpledialog({
            content : $('<div id="content1">Some even more awesome content (with buttons)</div>'),
            buttons : [{
                text : 'Click me',
                callback : function () {
                    window.calledCallback = true;
                }
            }]
        });

        $.each(['0', '1'], function (i) {

            QUnit.equal(
                typeof button[i].data('uiUiSimpledialog') === 'object',
                true,
                "typeof button[" + i + "].data('uiUiSimpledialog') === 'object'"
            );

            QUnit.equal(
                button[i].uiSimpledialog('option', 'layout'),
                layout,
                "Simpledialog on button[" + i + "] was rendered with '" + layout + "' layout."
            );
        });


        $.each(['0', '1'], function (i) {
            QUnit.equal(
                $._data(button[i][0], 'events') && $._data(button[i][0], 'events').click && $._data(button[i][0], 'events').click.length === 1,
                true,
                'button[' + i + '] has *click* handler'
            );
        });

        $.each(['0', '1'], function (i) {
            QUnit.equal(
                $('.ep-uiSimpledialog #content' + i).is(':visible'),
                i === 0, // Check, if *autoOpen* works.
                "$('.ep-uiSimpledialog #content' + i).is(':visible')"
            );
        });

        // Close dialog0.
        $('.ep-uiSimpledialog .ep-uiSimpledialog-head .ep-uiSimpledialog-close').trigger('click');
        // Open dialog1.
        button[1].trigger('click');

        $.each(['0', '1'], function (i) {
            QUnit.equal(
                $('.ep-uiSimpledialog #content' + i).is(':visible'),
                i === 1,
                "$('.ep-uiSimpledialog #content' + i).is(':visible')"
            );
        });

        // Click button of dialog1.
        $('.ep-uiSimpledialog .ep-uiSimpledialog-buttons button').first().trigger('click');
        QUnit.equal(
            window.calledCallback,
            true,
            '*callback* of *dialog1* button called'
        );

        setTimeout(function () {
            QUnit.equal(
                $._data($('html')[0], 'events').click && ($._data($('html')[0], 'events').click.length === 2),
                true,
                'The two *uiSimpledialog*s are listening for clicks on *html*'
            );

            // Click somewhere outside a dialog.
            $('#qunit-fixture').trigger('click');

            $('.ep-uiSimpledialog').each(function (i) {
                QUnit.equal(
                    $(this).is(':visible'),
                    false,
                    'Dialogs are visible'
                );
            });

            // Remove buttons and change content of dialog1.
            ep(button[1]).uiSimpledialog('option', {
                content : $('<div id="content1changed">Look at this! Content changed.</div>'),
                buttons : null
            });

            QUnit.equal(
                $('#content1changed').length === 1,
                true,
                'New content was added to dialog1'
            );

            QUnit.equal(
                $('.ep-uiSimpledialog .ep-uiSimpledialog-buttons').length === 0,
                true,
                'Buttons were removed'
            );

            // Destroy.
            $.each(['0', '1'], function (i) {
                button[i].uiSimpledialog('destroy');
            });

            $.each(['0', '1'], function (i) {
                QUnit.equal(
                    typeof button[i].data('epUiSimpledialog'),
                    'undefined',
                    "typeof button[" + i + "].data('epUiSimpledialog')"
                );
            });

            $.each(['0', '1'], function (i) {
                QUnit.equal(
                    $._data(button[i][0], 'events') && $._data(button[i][0], 'events').click,
                    undefined,
                    'button[' + i + '] has *click* handler'
                );
            });

            // Let's go, QUnit!
            QUnit.start();
        }, 200);
    });

    QUnit.asyncTest("ep/ui/simpledialog - scribe layout", function () {
        // clear HTML fragments and initiate fixture
        $('#qunit-fixture').nextAll().remove();
        QUnit.fixtureVar.init();

        var layout = 'scribe',
            button;

        // instantiate widget
        button = ep('#dialog0').uiSimpledialog({
            autoOpen : true,
            content : $('<div id="content0">Some (awesome) content</div>'),
            layout: layout
        });

        QUnit.ok(
            button.data('uiUiSimpledialog') !== undefined,
            "Simpledialog widget was instatiated."
        );

        QUnit.equal(
            button.uiSimpledialog('option', 'layout'),
            layout,
            "Simpledialog was rendered with '" + layout + "' layout."
        );
        QUnit.equal(
            $('.ep-uiSimpledialog-scribe').length,
            1,
            "Simpledialog gets the correct class 'ep-uiSimpledialog-scribe'."
        );

        // destroy simpledialog
        button.uiSimpledialog('destroy');

        QUnit.ok(
            button.data('uiUiSimpledialog') === undefined,
            "Simpledialog widget was destroyed."
        );

        // Let's go, QUnit!
        QUnit.start();
    });
});